<?php

namespace Drupal\time_based_registration\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\Core\Datetime\DrupalDateTime;

/**
 * Class TimeBasedRegistrationconfigration.
 */
class TimeBasedRegistrationconfigration extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'tbr.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'timebasedregistration_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    // Create the form object.
    $form['tbr_config'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Time Based Registration Settings'),
      '#collapsible' => FALSE,
      '#tree' => TRUE,
    ];

    $form['tbr_config']['desc'] = [
      '#markup' => $this->t('<br />Please set the timezone, from and to dates for user registration. <br />'),

    ];
    $form['tbr_config']['current_site_time_zone'] = [
      '#markup' => $this->t('Site Time zone is: <a href="@tbr-timezone">@tbr-link</a><br /> <br />', [
        '@tbr-timezone' => Url::fromRoute('system.regional_settings')->toString(),
        '@tbr-link' => drupal_get_user_timezone(),

      ]),
    ];

    // Get the values from config object.
    $tbr_config = $this->config('tbr.settings');

    if (isset($tbr_config)) {
      $time_based_from = $tbr_config->get('from_date');
      $time_based_to = $tbr_config->get('to_date');
    }

    // Create the input form elements.
    $form['tbr_config']['from_date'] = [
      '#type' => 'datetime',
      '#title' => 'From Date',
      '#required' => TRUE,
      '#default_value' => isset($time_based_from) ? DrupalDateTime::createFromTimestamp($time_based_from) : '',
      '#date_year_range' => '0:+1',
    ];
    $form['tbr_config']['to_date'] = [
      '#type' => 'datetime',
      '#title' => 'To Date',
      '#required' => TRUE,
      '#default_value' => isset($time_based_to) ? DrupalDateTime::createFromTimestamp($time_based_to) : '',
      '#date_year_range' => '0:+1',

    ];
    $form['actions']['#type'] = 'actions';
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
      '#button_type' => 'primary',
    ];

    // Return $form;.
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $from_date = $form_state->getValue('tbr_config')['from_date'];
    $to_date = $form_state->getValue('tbr_config')['to_date'];
    if ($from_date >= $to_date) {
      $form_state->setErrorByName('from_date', $this->t('From date should not be greater than To date.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state, $op = NULL) {

    // Get the values from form.
    $from_date = $form_state->getValue('tbr_config')['from_date'];
    $to_date = $form_state->getValue('tbr_config')['to_date'];

    $from_time = strtotime($from_date);
    $to_time = strtotime($to_date);
    $time = round(($to_time - $from_time) / 60);

    $day = floor($time / 1440);
    $hour = floor(($time - $day * 1440) / 60);
    $minute = $time - ($day * 1440) - ($hour * 60);
    drupal_set_message("Registration is available for $day day(s)  $hour hour(s)   $minute minute(s)");

    // Submit the form and store values in config.
    parent::submitForm($form, $form_state);
    $this->config('tbr.settings')
      ->set('from_date', $from_time)
      ->set('to_date', $to_time)
      ->save();

  }

}
